@@ -22,7 +22,7 @@
   This is beta software, please send bugs and/or comments to
   childsplay@users.sourceforge.net"""
   
-CPDEBUG=0
+CPDEBUG = 0
 import sys,os
 REDIRECT = 0
 
@@ -100,6 +100,7 @@ if SPLASH:
     except (Exception,pygame.error),info:
         print >> sys.stderr,info
         trace_error()
+    splash_worker = splash.Worker()# starts it self
 # Import other python stuff       
 try:
     import random,fnmatch,gettext,locale,pickle,threading,shutil,exceptions
@@ -556,14 +557,15 @@ class Contr(Score):
         self.backcol = (80,151,244)
         self.ttf = os.path.join(DATADIR,'Domestic_Manners.ttf')
         self.backgr = pygame.Surface((x,y))
-        
+        Assets_img.set_transparent_image(0)
+        Assets_img.set_alpha_image(1)
         files = ('land.png','stop.png','question1.png','hscore.png','tux.png',\
                 'OK_but.png','MORE_but.png','firework1.png','firework2.png')
         Assets_img.get_assets(files,Img)
         if CPDEBUG: print "Img.__dict__",Img.__dict__
-        
+        Assets_img.set_alpha_image(0)
         Assets_img.set_transparent_image(0)
-        Img.blue = Assets_img.get_assets(('blue.jpg',)) 
+        Img.blue = Assets_img.get_assets(('blue.png',)) 
         Assets_img.set_transparent_image(1)
         
         self.backgr.blit(Img.blue, (0,0))
@@ -913,13 +915,12 @@ def main():
     Snd.dub = load_sound(os.path.join(DATADIR,'dub.ogg'))
     Snd.thanks = load_sound(os.path.join(DATADIR,'thanks.ogg'))
     music_collection = [Snd.music1,Snd.galaga,Snd.dub,Snd.thanks]
-    #modul = 'Menu'
+    
     screendim = Dimmer(keepalive=1) # dimmer is used for screen copying
     screendim.dim(darken_factor=0) # just stores a copy in Dimmer.buffer
     screen  = c.screen
     back = c.backgr
     menu = CPMenu(screen,back,menudic,BASEDIR)
-    
     while 1:
         Snd.mainmusic = random.choice(music_collection)
         Snd.mainmusic.play(-1)
@@ -934,7 +935,7 @@ def main():
         try:
             # import game module
             game_module = import_module(os.path.join(LIBDIR,plugin_name+'.py'))
-                        
+            if CPDEBUG: print "imported module:",game_module
             try:
                 if game_module.RCFILE:# can we use a rcfile?
                     rcfile = plugin_name+'rc'
@@ -1038,11 +1039,13 @@ def main():
         
         
 if __name__ == '__main__':
+
     if SPLASH:
-        ############## Wait until the splash thread is finished ##########
-        while splash.thread.isAlive():
-            pass
-        #################   
+        # stop splash
+        try:
+           splash_worker.stop_splash()
+        except Exception,info:
+            print info
     try:
         main()
     finally:
